@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::Author::Plicease::Init2 2.43 {
+package Dist::Zilla::Plugin::Author::Plicease::Init2 2.44 {
 
   use 5.014;
   use Moose;
@@ -65,6 +65,23 @@ package Dist::Zilla::Plugin::Author::Plicease::Init2 2.43 {
     },
   );
 
+  has workflow => (
+    is      => 'ro',
+    isa     => 'ArrayRef[Str]',
+    lazy    => 1,
+    default => sub {
+      my $self = shift;
+      my @workflow;
+
+      foreach my $workflow (qw( windows macos ))
+      {
+        push @workflow, $workflow if $self->chrome->prompt_yn("workflow $workflow?");
+      }
+
+      \@workflow;
+    },
+  );
+
   has perl_version => (
     is      => 'ro',
     lazy    => 1,
@@ -139,14 +156,21 @@ package Dist::Zilla::Plugin::Author::Plicease::Init2 2.43 {
     $self->gather_file_simple  ('perlcriticrc');
     $self->gather_file_template('t/main_class.t' => 't/' . lc($self->zilla->name =~ s/-/_/gr) . ".t" );
     $self->gather_file_simple  ('xt/author/critic.t');
+
+    foreach my $workflow (@{ $self->workflow })
+    {
+      $self->gather_file_simple(".github/workflows/$workflow.yml");
+    }
   }
 
   sub gather_file_simple
   {
     my($self, $filename) = @_;
+    my $content = $self->section_data("dist/$filename");
+    $self->log_fatal("no bundled file dist/$filename") unless $content;
     my $file = Dist::Zilla::File::InMemory->new({
       name    => $filename,
-      content => ${ $self->section_data("dist/$filename") },
+      content => $$content,
     });
     $self->add_file($file);
   }
@@ -156,6 +180,7 @@ package Dist::Zilla::Plugin::Author::Plicease::Init2 2.43 {
     my($self, $template_name, $filename) = @_;
     $filename //= $template_name;
     my $template = ${ $self->section_data("template/$template_name") };
+    $self->log_fatal("no bundled template: template/$template_name") unless $template;
     my $content = $self->fill_in_string($template, {
       name         => $self->zilla->name,
       abstract     => $self->abstract,
@@ -174,16 +199,20 @@ package Dist::Zilla::Plugin::Author::Plicease::Init2 2.43 {
 
     my $zilla = $self->zilla;
 
-    my $template = ${ $self->section_data("template/dist.ini") };
+    my $template = $self->section_data("template/dist.ini");
+
+    my $stash = {
+      name           => $zilla->name,
+      copyright_year => (localtime)[5]+1900,
+      version        => __PACKAGE__->VERSION // '2.41',
+      release_tests  => $self->include_tests,
+      github_user    => $self->github_user,
+      version_plugin => ($self->perl_version >= 5.014 ? 'PkgVersion::Block' : 0),
+      workflow       => $self->workflow,
+    };
+
     my $code = sub {
-      $self->fill_in_string($template, {
-        name           => $zilla->name,
-        copyright_year => (localtime)[5]+1900,
-        version        => __PACKAGE__->VERSION // '2.41',
-        release_tests  => $self->include_tests,
-        github_user    => $self->github_user,
-        version_plugin => $self->perl_version >= 5.014 ? 'PkgVersion::Block' : 0,
-      }, {});
+      $self->fill_in_string($$template, $stash, {});
     };
 
     my $file = Dist::Zilla::File::FromCode->new({
@@ -343,7 +372,7 @@ Dist::Zilla::Plugin::Author::Plicease::Init2 - Dist::Zilla initialization tasks
 
 =head1 VERSION
 
-version 2.43
+version 2.44
 
 =head1 DESCRIPTION
 
@@ -564,7 +593,20 @@ release_tests  = {{$release_tests}}
 installer      = Author::Plicease::MakeMaker
 github_user    = {{$github_user}}
 test2_v0       = 1
-{{ $version_plugin ? "version_plugin = $version_plugin\n" : '' }}
+{{
+
+  my $extra = '';
+
+  foreach my $wf (@workflow)
+  {
+    $extra .= "workflow       = $wf\n";
+  }
+
+  $extra .= "version_plugin = $version_plugin\n" if $version_plugin;
+
+  $extra;
+
+}}
 [Author::Plicease::Core]
 
 [Author::Plicease::Upload]
@@ -657,3 +699,113 @@ package {{ $name =~ s/-/::/gr }} {
 
 1;
 
+
+__[ dist/.github/workflows/windows.yml ]__
+name: windows
+
+on:
+  push:
+    branches:
+      - '*'
+    tags-ignore:
+      - '*'
+  pull_request:
+
+env:
+  PERL5LIB: c:\cx\lib\perl5
+  PERL_LOCAL_LIB_ROOT: c:/cx
+  PERL_MB_OPT: --install_base C:/cx
+  PERL_MM_OPT: INSTALL_BASE=C:/cx
+
+jobs:
+  perl:
+
+    runs-on: windows-latest
+
+    steps:
+      - uses: actions/checkout@v2
+
+      - name: Cache CPAN modules
+        uses: actions/cache@v1
+        env:
+          cache-name: cache-cpan-modules
+        with:
+          path: c:\cx
+          key: ${{ runner.os }}-build-${{ env.cache-name }}
+          restore-keys: |
+            ${{ runner.os }}-build-${{ env.cache-name }}
+
+      - name: Set up Perl
+        run: |
+          choco install strawberryperl
+          echo "##[add-path]C:\cx\bin;C:\strawberry\c\bin;C:\strawberry\perl\site\bin;C:\strawberry\perl\bin"
+      - name: perl -V
+        run: perl -V
+      - name: Install Static Dependencies
+        run: |
+          cpanm -n Dist::Zilla
+          dzil authordeps --missing | cpanm -n
+          dzil listdeps --missing   | cpanm -n
+      - name: Install Dynamic Dependencies
+        run: |
+          dzil run 'cpanm --installdeps .'
+      - name: Run Tests
+        run: dzil test -v
+
+
+__[ dist/.github/workflows/windows.yml ]__
+name: macos
+
+on:
+  push:
+    branches:
+      - '*'
+    tags-ignore:
+      - '*'
+  pull_request:
+
+env:
+  PERL5LIB: /Users/runner/perl5/lib/perl5
+  PERL_LOCAL_LIB_ROOT: /Users/runner/perl5
+  PERL_MB_OPT: --install_base /Users/runner/perl5
+  PERL_MM_OPT: INSTALL_BASE=/Users/runner/perl5
+
+jobs:
+  perl:
+
+    runs-on: macOS-latest
+
+    steps:
+      - uses: actions/checkout@v2
+
+      - name: Set up Perl
+        run: |
+          brew install perl
+          curl https://cpanmin.us | perl - App::cpanminus -n
+          echo "##[add-path]/Users/runner/perl5/bin"
+
+      - name: perl -V
+        run: perl -V
+
+      - name: Prepare for cache
+        run: |
+          perl -V > perlversion.txt
+          ls -l perlversion.txt
+
+      - name: Cache CPAN modules
+        uses: actions/cache@v1
+        with:
+          path: ~/perl5
+          key: ${{ runner.os }}-build-${{ hashFiles('perlversion.txt') }}
+          restore-keys: |
+            ${{ runner.os }}-build-${{ hashFiles('perlversion.txt') }}
+
+      - name: Install Static Dependencies
+        run: |
+          cpanm -n Dist::Zilla
+          dzil authordeps --missing | cpanm -n
+          dzil listdeps --missing   | cpanm -n
+      - name: Install Dynamic Dependencies
+        run: dzil run 'cpanm --installdeps .'
+      - name: Run Tests
+        run: dzil test -v
